==> math2docx-2.0.2.tar.gz: math2docx-2.0.2/setup.py <==
# Импорт недавно установленного пакета setuptools.
import setuptools


requirements = ["python-docx", "mathml2omml", "latex2mathml"]


setuptools.setup(
    # Имя дистрибутива пакета. Оно должно быть уникальным, поэтому добавление вашего имени пользователя в конце является обычным делом.
    name="math2docx",
    # Номер версии вашего пакета. Обычно используется семантическое управление версиями.
    version="2.0.2",
    # Имя автора.
    author="Nikolay Markov",
    # Его почта.
    author_email="keh9mark@yandex.ru",
    # Краткое описание, которое будет показано на странице PyPi.
    description="Open source Python library converting math formula to docx",
    # Длинное описание, которое будет отображаться на странице PyPi. Использует README.md репозитория для заполнения.
    long_description="Open source Python library converting math formula to docx",
    # Определяет тип контента, используемый в long_description.
    long_description_content_type="text/markdown",
    # URL-адрес, представляющий домашнюю страницу проекта. Большинство проектов ссылаются на репозиторий.
    url="https://github.com/keh9mark/math2docx",
    # Находит все пакеты внутри проекта и объединяет их в дистрибутив.
    packages=setuptools.find_packages(),
    # requirements или dependencies, которые будут установлены вместе с пакетом, когда пользователь установит его через pip.
    install_requires=requirements,
    # Предоставляет pip некоторые метаданные о пакете. Также отображается на странице PyPi.
    classifiers=[
        "Programming Language :: Python :: 3.8",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    # Требуемая версия Python.
    python_requires=">=3.6",
)

==> math2docx-2.0.3.tar.gz: math2docx-2.0.3/setup.py <==
# Импорт недавно установленного пакета setuptools.
import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

requirements = ["python-docx", "mathml2omml", "latex2mathml"]


setuptools.setup(
    # Имя дистрибутива пакета. Оно должно быть уникальным, поэтому добавление вашего имени пользователя в конце является обычным делом.
    name="math2docx",
    # Номер версии вашего пакета. Обычно используется семантическое управление версиями.
    version="2.0.3",
    # Имя автора.
    author="Nikolay Markov",
    # Его почта.
    author_email="keh9mark@yandex.ru",
    # Краткое описание, которое будет показано на странице PyPi.
    description="Open source Python library converting math formula to docx",
    # Длинное описание, которое будет отображаться на странице PyPi. Использует README.md репозитория для заполнения.
    long_description=long_description,
    # Определяет тип контента, используемый в long_description.
    long_description_content_type="text/markdown",
    # URL-адрес, представляющий домашнюю страницу проекта. Большинство проектов ссылаются на репозиторий.
    url="https://github.com/keh9mark/math2docx",
    # Находит все пакеты внутри проекта и объединяет их в дистрибутив.
    packages=setuptools.find_packages(),
    # requirements или dependencies, которые будут установлены вместе с пакетом, когда пользователь установит его через pip.
    install_requires=requirements,
    # Предоставляет pip некоторые метаданные о пакете. Также отображается на странице PyPi.
    classifiers=[
        "Programming Language :: Python :: 3.8",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    # Требуемая версия Python.
    python_requires=">=3.6",
)
